@@ -164,6 +164,30 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateDBInstanceParamTpl(self, request):
+        """本接口(CreateDBInstanceParamTpl)用于创建云数据库MongoDB实例的参数模板
+        **说明：CreateDBInstanceParamTpl API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for CreateDBInstanceParamTpl.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.CreateDBInstanceParamTplRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.CreateDBInstanceParamTplResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDBInstanceParamTpl", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDBInstanceParamTplResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAccountUser(self, request):
         """本接口（DeleteAccountUser）用于删除实例的自定义账号。
 
@@ -256,6 +280,29 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBackupRules(self, request):
+        """本接口（DescribeBackupRules）用于获取实例自动备份配置信息。
+
+        :param request: Request instance for DescribeBackupRules.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeBackupRulesRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeBackupRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackupRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackupRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeClientConnections(self, request):
         """本接口（DescribeClientConnections）用于查询实例客户端连接信息，包括连接 IP 和连接数量。
 
@@ -371,6 +418,54 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDBInstanceParamTpl(self, request):
+        """本接口(DescribeDBInstanceParamTpl )用于查询当前账号下所有MongoDB数据库参数模板
+        **说明：DescribeDBInstanceParamTpl  API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for DescribeDBInstanceParamTpl.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceParamTplRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceParamTplResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDBInstanceParamTpl", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDBInstanceParamTplResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeDBInstanceParamTplDetail(self, request):
+        """本接口(DescribeDBInstanceParamTplDetail )用于查询MongoDB云数据库实例的参数模板详情。
+        **说明：DescribeDBInstanceParamTplDetail  API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for DescribeDBInstanceParamTplDetail.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceParamTplDetailRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeDBInstanceParamTplDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDBInstanceParamTplDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDBInstanceParamTplDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDBInstances(self, request):
         """本接口（DescribeDBInstances）用于查询云数据库实例列表，支持通过项目ID、实例ID、实例状态等过滤条件来筛选主实例、灾备实例和只读实例信息列表。
 
@@ -509,6 +604,100 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTransparentDataEncryptionStatus(self, request):
+        """获取实例透明加密的开启状态
+
+        :param request: Request instance for DescribeTransparentDataEncryptionStatus.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeTransparentDataEncryptionStatusRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeTransparentDataEncryptionStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTransparentDataEncryptionStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTransparentDataEncryptionStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DropDBInstanceParamTpl(self, request):
+        """本接口(DropDBInstanceParamTpl )用于删除云数据库MongoDB实例的参数模板
+        **说明：DropDBInstanceParamTpl  API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for DropDBInstanceParamTpl.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DropDBInstanceParamTplRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DropDBInstanceParamTplResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DropDBInstanceParamTpl", params, headers=headers)
+            response = json.loads(body)
+            model = models.DropDBInstanceParamTplResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def EnableTransparentDataEncryption(self, request):
+        """本接口(EnableTransparentDataEncryption)用于开启云数据库 MongoDB 的透明加密能力。
+
+        :param request: Request instance for EnableTransparentDataEncryption.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.EnableTransparentDataEncryptionRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.EnableTransparentDataEncryptionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("EnableTransparentDataEncryption", params, headers=headers)
+            response = json.loads(body)
+            model = models.EnableTransparentDataEncryptionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def FlashBackDBInstance(self, request):
+        """该接口用于发起按 Key 闪回任务，依据数据的闪回 Key（默认为 id）对数据进行极速回档，快速恢复业务。
+        **说明：按 Key 闪回于2023年09月11日正式进行公测，在此期间，该接口仅对公测用户开放。**
+
+        :param request: Request instance for FlashBackDBInstance.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.FlashBackDBInstanceRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.FlashBackDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("FlashBackDBInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.FlashBackDBInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def FlushInstanceRouterConfig(self, request):
         """在所有mongos上执行FlushRouterConfig命令
 
@@ -648,7 +837,7 @@ class MongodbClient(AbstractClient):
 
 
     def ModifyDBInstanceNetworkAddress(self, request):
-        """本接口(ModifyDBInstanceNetworkAddress)用于修改云数据库实例的网络信息，可进行基础网络转VPC网络和VPC网络之间的变换。
+        """本接口（ModifyDBInstanceNetworkAddress）用于修改云数据库实例的网络信息，支持基础网络切换为私有网络、私有网络切换私有网络。
 
         :param request: Request instance for ModifyDBInstanceNetworkAddress.
         :type request: :class:`tencentcloud.mongodb.v20190725.models.ModifyDBInstanceNetworkAddressRequest`
@@ -670,6 +859,30 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyDBInstanceParamTpl(self, request):
+        """本接口(ModifyDBInstanceParamTpl )用于修改MongoDB云数据库实例的参数模板。
+        **说明：ModifyDBInstanceParamTpl  API正在公测中，在此期间，该接口仅对公测用户开放**
+
+        :param request: Request instance for ModifyDBInstanceParamTpl.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.ModifyDBInstanceParamTplRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.ModifyDBInstanceParamTplResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDBInstanceParamTpl", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDBInstanceParamTplResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDBInstanceSecurityGroup(self, request):
         """本接口（ModifyDBInstanceSecurityGroup）用于修改实例绑定的安全组
 
@@ -716,6 +929,29 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstanceParams(self, request):
+        """本接口（ModifyInstanceParams）用于修改mongoDB实例的参数配置。
+
+        :param request: Request instance for ModifyInstanceParams.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.ModifyInstanceParamsRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.ModifyInstanceParamsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceParams", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceParamsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def OfflineIsolatedDBInstance(self, request):
         """本接口(OfflineIsolatedDBInstance)用于立即下线隔离状态的云数据库实例。进行操作的实例状态必须为隔离状态。
 
@@ -831,6 +1067,52 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SetBackupRules(self, request):
+        """本接口(SetBackupRules)用于设置 MongoDB 云数据库的自动备份规则。
+
+        :param request: Request instance for SetBackupRules.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.SetBackupRulesRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.SetBackupRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SetBackupRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.SetBackupRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def SetInstanceMaintenance(self, request):
+        """本接口（SetInstanceMaintenance ） 用于设置实例维护时间窗。
+
+        :param request: Request instance for SetInstanceMaintenance.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.SetInstanceMaintenanceRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.SetInstanceMaintenanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SetInstanceMaintenance", params, headers=headers)
+            response = json.loads(body)
+            model = models.SetInstanceMaintenanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def TerminateDBInstances(self, request):
         """本接口（TerminateDBInstances）可将包年包月实例退还隔离。
 
